@@ -32,11 +32,11 @@ Test::Run::Core - Base class to run standard TAP scripts.
 
 =head1 VERSION
 
-Version 0.0303
+Version 0.0304
 
 =cut
 
-$VERSION = '0.0303';
+$VERSION = '0.0304';
 
 $ENV{HARNESS_ACTIVE} = 1;
 $ENV{HARNESS_NG_VERSION} = $VERSION;
@@ -2060,7 +2060,7 @@ Test::Harness was then maintained by Andy Lester C<< <andy at petdance.com> >>.
 
 =head2 Test::Run::Obj Authors
 
-Shlomi Fish C<< <shlomif@iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 Note: this file is a rewrite of the original Test::Run code in order to
 change to a more liberal license.
