@@ -39,7 +39,7 @@ http://www.opensource.org/licenses/mit-license.php
 
 =head1 AUTHOR
 
-Shlomi Fish <shlomif@iglu.org.il>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =cut
 
